#
# spec file for package perl-Protocol-WebSocket
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name Protocol-WebSocket
Name:           perl-Protocol-WebSocket
Version:        0.260.0
Release:        1.1
# 0.26 -> normalize -> 0.260.0
%define cpan_version 0.26
License:        Artistic-1.0 OR GPL-1.0-or-later
Summary:        WebSocket protocol
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/V/VT/VTI/%{cpan_name}-%{cpan_version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(Digest::SHA)
BuildRequires:  perl(Module::Build)
BuildRequires:  perl(Module::Build::Tiny) >= 0.35
Requires:       perl(Digest::SHA)
Provides:       perl(Protocol::WebSocket) = %{version}
Provides:       perl(Protocol::WebSocket::Client)
Provides:       perl(Protocol::WebSocket::Cookie)
Provides:       perl(Protocol::WebSocket::Cookie::Request)
Provides:       perl(Protocol::WebSocket::Cookie::Response)
Provides:       perl(Protocol::WebSocket::Frame)
Provides:       perl(Protocol::WebSocket::Handshake)
Provides:       perl(Protocol::WebSocket::Handshake::Client)
Provides:       perl(Protocol::WebSocket::Handshake::Server)
Provides:       perl(Protocol::WebSocket::Message)
Provides:       perl(Protocol::WebSocket::Request)
Provides:       perl(Protocol::WebSocket::Response)
Provides:       perl(Protocol::WebSocket::Stateful)
Provides:       perl(Protocol::WebSocket::URL)
%undefine       __perllib_provides
%{perl_requires}

%description
Client/server WebSocket message and frame parser/constructor. This module
does not provide a WebSocket server or client, but is made for using in
http servers or clients to provide WebSocket support.

Protocol::WebSocket supports the following WebSocket protocol versions:

    draft-ietf-hybi-17 (latest)
    draft-ietf-hybi-10
    draft-ietf-hybi-00 (with HAProxy support)
    draft-hixie-75

By default the latest version is used. The WebSocket version is detected
automatically on the server side. On the client side you have set a
'version' attribute to an appropriate value.

Protocol::WebSocket itself does not contain any code and cannot be used
directly. Instead the following modules should be used:

%prep
%autosetup -n %{cpan_name}-%{cpan_version} -p1

find . -type f ! -path "*/t/*" ! -name "*.pl" ! -path "*/bin/*" ! -path "*/script/*" ! -path "*/scripts/*" ! -name "configure" -print0 | xargs -0 chmod 644

%build
perl Build.PL --installdirs=vendor
./Build build --flags=%{?_smp_mflags}

%check
./Build test

%install
./Build install --destdir=%{buildroot} --create_packlist=0
%perl_gen_filelist

%files -f %{name}.files
%doc Changes examples README.md util
%license LICENSE

%changelog
* Tue Jun  3 2025 Tina Müller <tina.mueller@suse.com>
- Normalize CPAN version
  See https://github.com/openSUSE/cpanspec/issues/47 for details
* Wed Mar 13 2019 Stephan Kulow <coolo@suse.com>
- updated to 0.26
  see /usr/share/doc/packages/perl-Protocol-WebSocket/Changes
  0.26 2019-03-09T09:35:15Z
  - Introduce MAX_FRAGMENTS_AMOUNT to change the allowable amount of fragments (Daniel Kamil Kozar)
  - Update draft-ietf-hybi-00 tests to include the error text in response line (Daniel Kamil Kozar)
  0.25 2019-03-09T09:31:45Z
  - The "Wrong response line" error now includes the actual response line (Max Maischein)
* Sun Jan 14 2018 coolo@suse.com
- updated to 0.24
  see /usr/share/doc/packages/perl-Protocol-WebSocket/Changes
  0.24 2018-01-13T09:59:07Z
  - draft-ietf-hybi-17 uses origin header, not sec-websocket-origin (Eric Wastl)
* Wed Dec 13 2017 coolo@suse.com
- updated to 0.23
  see /usr/share/doc/packages/perl-Protocol-WebSocket/Changes
  0.23 2017-12-12T19:16:32Z
  - revert previous release
* Sat Dec  9 2017 coolo@suse.com
- updated to 0.22
  see /usr/share/doc/packages/perl-Protocol-WebSocket/Changes
  0.22 2017-12-08T17:24:15Z
  - reliable UTF-8 bahaviour (Paul "LeoNerd" Evans #GH-35, #GH-52)
  - document masked frame attribute
* Tue Sep  5 2017 coolo@suse.com
- updated to 0.21
  see /usr/share/doc/packages/perl-Protocol-WebSocket/Changes
  0.21 2017-09-04T17:06:56Z
  - MAX_PAYLOAD_SIZE global var
  - MAX_MESSAGE_SIZE global var
* Sat Nov  5 2016 coolo@suse.com
- updated to 0.20
  see /usr/share/doc/packages/perl-Protocol-WebSocket/Changes
  0.20 2016-11-04T18:21:37Z
  - RSV bit (Anton Petrusevich)
  - do not modify passed headers structure (Graham Ollis)
  - bypass max payload size (Graham Ollis)
* Sun Oct  4 2015 coolo@suse.com
- updated to 0.19
  see /usr/share/doc/packages/perl-Protocol-WebSocket/Changes
  0.19 2015-09-28T16:55:01Z
  - custom headers in request
  - fix wrong UTF-8 related documentation (#GH-13)
* Tue Apr 14 2015 coolo@suse.com
- updated to 0.18
  see /usr/share/doc/packages/perl-Protocol-WebSocket/Changes
* Tue Oct  1 2013 coolo@suse.com
- initial package 0.12
  * created by cpanspec 1.78.07
